

Instrument
===========================

.. currentmodule:: poppy.instrument

.. autoclass:: Instrument
   :show-inheritance:

   
     
   

   
   

   .. rubric:: Attributes Summary

   .. autosummary::
   
      ~Instrument.filter

   
   

   
   

   .. rubric:: Methods Summary

   .. autosummary::
   
      ~Instrument.calcPSF
      ~Instrument.display

   
   

   
   

   .. rubric:: Attributes Documentation

   
   .. autoattribute:: filter

   
   

   
   

   .. rubric:: Methods Documentation

   
   .. automethod:: calcPSF
   .. automethod:: display

   
   